@@ -35,9 +35,7 @@ You can do the following:
 			return
 		}
 		env := &platform.Shell{
-			CmdFlags: &platform.Flags{
-				Version: cliVersion,
-			},
+			CmdFlags: &platform.Flags{},
 		}
 		env.Init()
 		defer env.Close()
@@ -59,7 +57,7 @@ You can do the following:
 	},
 }
 
-func init() { //nolint:gochecknoinits
+func init() {
 	RootCmd.AddCommand(getCache)
 }
 
